/****************************************************************************
** Meta object code from reading C++ file 'enum.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-thunderbolt-6.6.5/src/lib/enum.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'enum.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4BoltE_t {};
} // unnamed namespace

template <> constexpr inline auto Bolt::qt_create_metaobjectdata<qt_meta_tag_ZN4BoltE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Bolt",
        "Status",
        "Unknown",
        "Disconnected",
        "Connecting",
        "Connected",
        "Authorizing",
        "AuthError",
        "Authorized",
        "Auth",
        "None",
        "NoPCIE",
        "Secure",
        "NoKey",
        "Boot",
        "KeyState",
        "Missing",
        "Have",
        "New",
        "Policy",
        "Default",
        "Manual",
        "Auto",
        "Type",
        "Host",
        "Peripheral",
        "AuthMode",
        "Disabled",
        "Enabled",
        "Security",
        "DPOnly",
        "User",
        "USBOnly"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Status'
        QtMocHelpers::EnumData<Status>(1, 1, QMC::EnumIsScoped).add({
            {    2, Status::Unknown },
            {    3, Status::Disconnected },
            {    4, Status::Connecting },
            {    5, Status::Connected },
            {    6, Status::Authorizing },
            {    7, Status::AuthError },
            {    8, Status::Authorized },
        }),
        // enum 'Auth'
        QtMocHelpers::EnumData<Auth>(9, 9, QMC::EnumIsScoped).add({
            {   10, Auth::None },
            {   11, Auth::NoPCIE },
            {   12, Auth::Secure },
            {   13, Auth::NoKey },
            {   14, Auth::Boot },
        }),
        // enum 'KeyState'
        QtMocHelpers::EnumData<KeyState>(15, 15, QMC::EnumIsScoped).add({
            {    2, KeyState::Unknown },
            {   16, KeyState::Missing },
            {   17, KeyState::Have },
            {   18, KeyState::New },
        }),
        // enum 'Policy'
        QtMocHelpers::EnumData<Policy>(19, 19, QMC::EnumIsScoped).add({
            {    2, Policy::Unknown },
            {   20, Policy::Default },
            {   21, Policy::Manual },
            {   22, Policy::Auto },
        }),
        // enum 'Type'
        QtMocHelpers::EnumData<Type>(23, 23, QMC::EnumIsScoped).add({
            {    2, Type::Unknown },
            {   24, Type::Host },
            {   25, Type::Peripheral },
        }),
        // enum 'AuthMode'
        QtMocHelpers::EnumData<AuthMode>(26, 26, QMC::EnumIsScoped).add({
            {   27, AuthMode::Disabled },
            {   28, AuthMode::Enabled },
        }),
        // enum 'Security'
        QtMocHelpers::EnumData<Security>(29, 29, QMC::EnumIsScoped).add({
            {    2, Security::Unknown },
            {   10, Security::None },
            {   30, Security::DPOnly },
            {   31, Security::User },
            {   12, Security::Secure },
            {   32, Security::USBOnly },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN4BoltE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN4BoltE =
    Bolt::qt_create_metaobjectdata<qt_meta_tag_ZN4BoltE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN4BoltE =
    qt_staticMetaObjectContent_ZN4BoltE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN4BoltE =
    qt_staticMetaObjectContent_ZN4BoltE.relocatingData;

Q_CONSTINIT const QMetaObject Bolt::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN4BoltE.stringdata,
    qt_staticMetaObjectStaticContent_ZN4BoltE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN4BoltE.metaTypes,
    nullptr
} };

QT_WARNING_POP
