/****************************************************************************
** Meta object code from reading C++ file 'manager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-thunderbolt-6.6.5/src/lib/manager.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QSharedPointer>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'manager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Bolt7ManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto Bolt::Manager::qt_create_metaobjectdata<qt_meta_tag_ZN4Bolt7ManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Bolt::Manager",
        "deviceAdded",
        "",
        "QSharedPointer<Bolt::Device>",
        "device",
        "deviceRemoved",
        "authModeChanged",
        "Bolt::AuthMode",
        "authMode",
        "uid",
        "QDBusObjectPath",
        "path",
        "devices",
        "QList<QSharedPointer<Bolt::Device>>",
        "isAvailable",
        "version",
        "isProbing",
        "defaultPolicy",
        "Bolt::Policy",
        "securityLevel",
        "Bolt::Security"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'deviceAdded'
        QtMocHelpers::SignalData<void(const QSharedPointer<Bolt::Device> &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'deviceRemoved'
        QtMocHelpers::SignalData<void(const QSharedPointer<Bolt::Device> &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'authModeChanged'
        QtMocHelpers::SignalData<void(Bolt::AuthMode)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Method 'device'
        QtMocHelpers::MethodData<QSharedPointer<Bolt::Device>(const QString &) const>(4, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { QMetaType::QString, 9 },
        }}),
        // Method 'device'
        QtMocHelpers::MethodData<QSharedPointer<Bolt::Device>(const QDBusObjectPath &) const>(4, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Method 'devices'
        QtMocHelpers::MethodData<QList<QSharedPointer<Bolt::Device>>() const>(12, 2, QMC::AccessPublic, 0x80000000 | 13),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'isAvailable'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'version'
        QtMocHelpers::PropertyData<uint>(15, QMetaType::UInt, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::Constant),
        // property 'isProbing'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::Constant),
        // property 'defaultPolicy'
        QtMocHelpers::PropertyData<Bolt::Policy>(17, 0x80000000 | 18, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::EnumOrFlag | QMC::Constant),
        // property 'securityLevel'
        QtMocHelpers::PropertyData<Bolt::Security>(19, 0x80000000 | 20, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::EnumOrFlag | QMC::Constant),
        // property 'authMode'
        QtMocHelpers::PropertyData<Bolt::AuthMode>(8, 0x80000000 | 7, QMC::Readable | QMC::Writable | QMC::Designable | QMC::Scriptable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Manager, qt_meta_tag_ZN4Bolt7ManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN4Bolt7ManagerE[] = {
    QMetaObject::SuperData::link<Bolt::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject Bolt::Manager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Bolt7ManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Bolt7ManagerE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN4Bolt7ManagerE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Bolt7ManagerE_t>.metaTypes,
    nullptr
} };

void Bolt::Manager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Manager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->deviceAdded((*reinterpret_cast<std::add_pointer_t<QSharedPointer<Bolt::Device>>>(_a[1]))); break;
        case 1: _t->deviceRemoved((*reinterpret_cast<std::add_pointer_t<QSharedPointer<Bolt::Device>>>(_a[1]))); break;
        case 2: _t->authModeChanged((*reinterpret_cast<std::add_pointer_t<Bolt::AuthMode>>(_a[1]))); break;
        case 3: { QSharedPointer<Bolt::Device> _r = _t->device((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QSharedPointer<Bolt::Device>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QSharedPointer<Bolt::Device> _r = _t->device((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QSharedPointer<Bolt::Device>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QList<QSharedPointer<Bolt::Device>> _r = _t->devices();
            if (_a[0]) *reinterpret_cast<QList<QSharedPointer<Bolt::Device>>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Bolt::AuthMode >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Manager::*)(const QSharedPointer<Bolt::Device> & )>(_a, &Manager::deviceAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)(const QSharedPointer<Bolt::Device> & )>(_a, &Manager::deviceRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Manager::*)(Bolt::AuthMode )>(_a, &Manager::authModeChanged, 2))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Bolt::AuthMode >(); break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Bolt::Policy >(); break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Bolt::Security >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isAvailable(); break;
        case 1: *reinterpret_cast<uint*>(_v) = _t->version(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isProbing(); break;
        case 3: *reinterpret_cast<Bolt::Policy*>(_v) = _t->defaultPolicy(); break;
        case 4: *reinterpret_cast<Bolt::Security*>(_v) = _t->securityLevel(); break;
        case 5: *reinterpret_cast<Bolt::AuthMode*>(_v) = _t->authMode(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 5: _t->setAuthMode(*reinterpret_cast<Bolt::AuthMode*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Bolt::Manager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Bolt::Manager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Bolt7ManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Bolt::Manager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void Bolt::Manager::deviceAdded(const QSharedPointer<Bolt::Device> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Bolt::Manager::deviceRemoved(const QSharedPointer<Bolt::Device> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Bolt::Manager::authModeChanged(Bolt::AuthMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
