/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.bolt1.device.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef DEVICEINTERFACE_H
#define DEVICEINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.freedesktop.bolt1.Device
 */
class OrgFreedesktopBolt1DeviceInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.freedesktop.bolt1.Device"; }

public:
    OrgFreedesktopBolt1DeviceInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgFreedesktopBolt1DeviceInterface();

    Q_PROPERTY(QString AuthFlags READ authFlags)
    inline QString authFlags() const
    { return qvariant_cast< QString >(property("AuthFlags")); }

    Q_PROPERTY(qulonglong AuthorizeTime READ authorizeTime)
    inline qulonglong authorizeTime() const
    { return qvariant_cast< qulonglong >(property("AuthorizeTime")); }

    Q_PROPERTY(qulonglong ConnectTime READ connectTime)
    inline qulonglong connectTime() const
    { return qvariant_cast< qulonglong >(property("ConnectTime")); }

    Q_PROPERTY(QString Key READ key)
    inline QString key() const
    { return qvariant_cast< QString >(property("Key")); }

    Q_PROPERTY(QString Label READ label WRITE setLabel)
    inline QString label() const
    { return qvariant_cast< QString >(property("Label")); }
    inline void setLabel(const QString &value)
    { setProperty("Label", QVariant::fromValue(value)); }

    Q_PROPERTY(QString Name READ name)
    inline QString name() const
    { return qvariant_cast< QString >(property("Name")); }

    Q_PROPERTY(QString Parent READ parentUid)
    inline QString parentUid() const
    { return qvariant_cast< QString >(property("Parent")); }

    Q_PROPERTY(QString Policy READ policy)
    inline QString policy() const
    { return qvariant_cast< QString >(property("Policy")); }

    Q_PROPERTY(QString Status READ status)
    inline QString status() const
    { return qvariant_cast< QString >(property("Status")); }

    Q_PROPERTY(qulonglong StoreTime READ storeTime)
    inline qulonglong storeTime() const
    { return qvariant_cast< qulonglong >(property("StoreTime")); }

    Q_PROPERTY(bool Stored READ stored)
    inline bool stored() const
    { return qvariant_cast< bool >(property("Stored")); }

    Q_PROPERTY(QString SysfsPath READ sysfsPath)
    inline QString sysfsPath() const
    { return qvariant_cast< QString >(property("SysfsPath")); }

    Q_PROPERTY(QString Type READ type)
    inline QString type() const
    { return qvariant_cast< QString >(property("Type")); }

    Q_PROPERTY(QString Uid READ uid)
    inline QString uid() const
    { return qvariant_cast< QString >(property("Uid")); }

    Q_PROPERTY(QString Vendor READ vendor)
    inline QString vendor() const
    { return qvariant_cast< QString >(property("Vendor")); }

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> Authorize(const QString &flags)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(flags);
        return asyncCallWithArgumentList(QStringLiteral("Authorize"), argumentList);
    }

Q_SIGNALS: // SIGNALS
};

namespace org {
  namespace freedesktop {
    namespace bolt1 {
      using Device = ::OrgFreedesktopBolt1DeviceInterface;
    }
  }
}

#endif
