/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.bolt1.manager.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef MANAGERINTERFACE_H
#define MANAGERINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.freedesktop.bolt1.Manager
 */
class OrgFreedesktopBolt1ManagerInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.freedesktop.bolt1.Manager"; }

public:
    OrgFreedesktopBolt1ManagerInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgFreedesktopBolt1ManagerInterface();

    Q_PROPERTY(QString AuthMode READ authMode WRITE setAuthMode)
    inline QString authMode() const
    { return qvariant_cast< QString >(property("AuthMode")); }
    inline void setAuthMode(const QString &value)
    { setProperty("AuthMode", QVariant::fromValue(value)); }

    Q_PROPERTY(QString DefaultPolicy READ defaultPolicy)
    inline QString defaultPolicy() const
    { return qvariant_cast< QString >(property("DefaultPolicy")); }

    Q_PROPERTY(bool Probing READ probing)
    inline bool probing() const
    { return qvariant_cast< bool >(property("Probing")); }

    Q_PROPERTY(QString SecurityLevel READ securityLevel)
    inline QString securityLevel() const
    { return qvariant_cast< QString >(property("SecurityLevel")); }

    Q_PROPERTY(uint Version READ version)
    inline uint version() const
    { return qvariant_cast< uint >(property("Version")); }

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<QDBusObjectPath> DeviceByUid(const QString &uid)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(uid);
        return asyncCallWithArgumentList(QStringLiteral("DeviceByUid"), argumentList);
    }

    inline QDBusPendingReply<QDBusObjectPath> EnrollDevice(const QString &uid, const QString &policy, const QString &flags)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(uid) << QVariant::fromValue(policy) << QVariant::fromValue(flags);
        return asyncCallWithArgumentList(QStringLiteral("EnrollDevice"), argumentList);
    }

    inline QDBusPendingReply<> ForgetDevice(const QString &uid)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(uid);
        return asyncCallWithArgumentList(QStringLiteral("ForgetDevice"), argumentList);
    }

    inline QDBusPendingReply<QList<QDBusObjectPath> > ListDevices()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("ListDevices"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void DeviceAdded(const QDBusObjectPath &device);
    void DeviceRemoved(const QDBusObjectPath &device);
};

namespace org {
  namespace freedesktop {
    namespace bolt1 {
      using Manager = ::OrgFreedesktopBolt1ManagerInterface;
    }
  }
}

#endif
