/****************************************************************************
** Meta object code from reading C++ file 'device.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../plasma-thunderbolt-6.6.5/src/lib/device.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'device.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Bolt6DeviceE_t {};
} // unnamed namespace

template <> constexpr inline auto Bolt::Device::qt_create_metaobjectdata<qt_meta_tag_ZN4Bolt6DeviceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Bolt::Device",
        "statusChanged",
        "",
        "Bolt::Status",
        "storedChanged",
        "stored",
        "policyChanged",
        "Bolt::Policy",
        "policy",
        "authFlagsChanged",
        "Bolt::AuthFlags",
        "authFlags",
        "uid",
        "name",
        "vendor",
        "type",
        "Bolt::Type",
        "status",
        "parent",
        "sysfsPath",
        "connectTime",
        "authorizeTime",
        "keyState",
        "Bolt::KeyState",
        "storeTime",
        "label"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void(Bolt::Status)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'storedChanged'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'policyChanged'
        QtMocHelpers::SignalData<void(Bolt::Policy)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'authFlagsChanged'
        QtMocHelpers::SignalData<void(Bolt::AuthFlags)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'uid'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::Constant),
        // property 'vendor'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::Constant),
        // property 'type'
        QtMocHelpers::PropertyData<Bolt::Type>(15, 0x80000000 | 16, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::EnumOrFlag | QMC::Constant),
        // property 'status'
        QtMocHelpers::PropertyData<Bolt::Status>(17, 0x80000000 | 3, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::EnumOrFlag, 0),
        // property 'authFlags'
        QtMocHelpers::PropertyData<Bolt::AuthFlags>(11, 0x80000000 | 10, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::EnumOrFlag, 3),
        // property 'parent'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::Constant),
        // property 'sysfsPath'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::Constant),
        // property 'connectTime'
        QtMocHelpers::PropertyData<QDateTime>(20, QMetaType::QDateTime, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::Constant),
        // property 'authorizeTime'
        QtMocHelpers::PropertyData<QDateTime>(21, QMetaType::QDateTime, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::Constant),
        // property 'stored'
        QtMocHelpers::PropertyData<bool>(5, QMetaType::Bool, QMC::Readable | QMC::Designable | QMC::Scriptable, 1),
        // property 'policy'
        QtMocHelpers::PropertyData<Bolt::Policy>(8, 0x80000000 | 7, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::EnumOrFlag, 2),
        // property 'keyState'
        QtMocHelpers::PropertyData<Bolt::KeyState>(22, 0x80000000 | 23, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::EnumOrFlag | QMC::Constant),
        // property 'storeTime'
        QtMocHelpers::PropertyData<QDateTime>(24, QMetaType::QDateTime, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::Constant),
        // property 'label'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Device, qt_meta_tag_ZN4Bolt6DeviceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN4Bolt6DeviceE[] = {
    QMetaObject::SuperData::link<Bolt::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject Bolt::Device::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Bolt6DeviceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Bolt6DeviceE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN4Bolt6DeviceE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Bolt6DeviceE_t>.metaTypes,
    nullptr
} };

void Bolt::Device::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Device *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->statusChanged((*reinterpret_cast<std::add_pointer_t<Bolt::Status>>(_a[1]))); break;
        case 1: _t->storedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->policyChanged((*reinterpret_cast<std::add_pointer_t<Bolt::Policy>>(_a[1]))); break;
        case 3: _t->authFlagsChanged((*reinterpret_cast<std::add_pointer_t<Bolt::AuthFlags>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Bolt::Status >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Bolt::Policy >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Bolt::AuthFlags >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Device::*)(Bolt::Status )>(_a, &Device::statusChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)(bool )>(_a, &Device::storedChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)(Bolt::Policy )>(_a, &Device::policyChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Device::*)(Bolt::AuthFlags )>(_a, &Device::authFlagsChanged, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Bolt::AuthFlags >(); break;
        case 12:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Bolt::KeyState >(); break;
        case 11:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Bolt::Policy >(); break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Bolt::Status >(); break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Bolt::Type >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->uid(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->vendor(); break;
        case 3: *reinterpret_cast<Bolt::Type*>(_v) = _t->type(); break;
        case 4: *reinterpret_cast<Bolt::Status*>(_v) = _t->status(); break;
        case 5: *reinterpret_cast<Bolt::AuthFlags*>(_v) = _t->authFlags(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->parent(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->sysfsPath(); break;
        case 8: *reinterpret_cast<QDateTime*>(_v) = _t->connectTime(); break;
        case 9: *reinterpret_cast<QDateTime*>(_v) = _t->authorizeTime(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->stored(); break;
        case 11: *reinterpret_cast<Bolt::Policy*>(_v) = _t->policy(); break;
        case 12: *reinterpret_cast<Bolt::KeyState*>(_v) = _t->keyState(); break;
        case 13: *reinterpret_cast<QDateTime*>(_v) = _t->storeTime(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->label(); break;
        default: break;
        }
    }
}

const QMetaObject *Bolt::Device::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Bolt::Device::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Bolt6DeviceE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QEnableSharedFromThis<Device>"))
        return static_cast< QEnableSharedFromThis<Device>*>(this);
    return QObject::qt_metacast(_clname);
}

int Bolt::Device::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void Bolt::Device::statusChanged(Bolt::Status _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Bolt::Device::storedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Bolt::Device::policyChanged(Bolt::Policy _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Bolt::Device::authFlagsChanged(Bolt::AuthFlags _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
